Coverage report

|  |  | Statements |  | Branches |  | Total
--- | --- | --- | --- | --- | --- | --- | ---
File | function |  | coverage | statements | missing | excluded |  | coverage | branches | partial |  | coverage
src / kiss / agents / sorcar / sorcar.py | _read_active_file |  | 100% | 9 | 0 | 0 |  | 100% | 2 | 0 |  | 100%
src / kiss / agents / sorcar / sorcar.py | _clean_llm_output |  | 100% | 1 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src / kiss / agents / sorcar / sorcar.py | _generate_commit_msg |  | 70% | 10 | 3 | 0 |  | 100% | 2 | 0 |  | 75%
src / kiss / agents / sorcar / sorcar.py | _model_vendor_order |  | 100% | 11 | 0 | 0 |  | 100% | 10 | 0 |  | 100%
src / kiss / agents / sorcar / sorcar.py | run_chatbot |  | 59% | 187 | 77 | 0 |  | 19% | 26 | 5 |  | 54%
src / kiss / agents / sorcar / sorcar.py | run_chatbot._code_server_launch_args |  | 0% | 2 | 2 | 0 |  | 100% | 0 | 0 |  | 0%
src / kiss / agents / sorcar / sorcar.py | run_chatbot._watch_code_server |  | 0% | 30 | 30 | 0 |  | 0% | 12 | 0 |  | 0%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.refresh_file_cache |  | 100% | 1 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.refresh_proposed_tasks |  | 67% | 21 | 7 | 0 |  | 50% | 2 | 1 |  | 65%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.generate_followup |  | 75% | 8 | 2 | 0 |  | 50% | 2 | 1 |  | 70%
src / kiss / agents / sorcar / sorcar.py | run_chatbot._watch_theme_file |  | 75% | 20 | 5 | 0 |  | 88% | 8 | 1 |  | 79%
src / kiss / agents / sorcar / sorcar.py | run_chatbot._watch_no_clients |  | 100% | 11 | 0 | 0 |  | 90% | 10 | 1 |  | 95%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.run_agent_thread |  | 94% | 67 | 4 | 0 |  | 93% | 14 | 1 |  | 94%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.stop_agent |  | 100% | 16 | 0 | 0 |  | 67% | 6 | 2 |  | 91%
src / kiss / agents / sorcar / sorcar.py | run_chatbot._cleanup |  | 29% | 24 | 17 | 0 |  | 50% | 6 | 3 |  | 33%
src / kiss / agents / sorcar / sorcar.py | run_chatbot._do_shutdown |  | 83% | 6 | 1 | 0 |  | 50% | 2 | 1 |  | 75%
src / kiss / agents / sorcar / sorcar.py | run_chatbot._cancel_shutdown |  | 100% | 4 | 0 | 0 |  | 50% | 2 | 1 |  | 83%
src / kiss / agents / sorcar / sorcar.py | run_chatbot._schedule_shutdown |  | 82% | 11 | 2 | 0 |  | 67% | 6 | 2 |  | 76%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.index |  | 100% | 1 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.events |  | 100% | 4 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.events.generate |  | 96% | 24 | 1 | 0 |  | 75% | 8 | 2 |  | 91%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.run_task |  | 100% | 22 | 0 | 0 |  | 100% | 8 | 0 |  | 100%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.run_selection |  | 100% | 21 | 0 | 0 |  | 100% | 8 | 0 |  | 100%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.stop_task |  | 100% | 3 | 0 | 0 |  | 100% | 2 | 0 |  | 100%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.suggestions |  | 100% | 44 | 0 | 0 |  | 100% | 30 | 0 |  | 100%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.tasks |  | 100% | 2 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.task_events |  | 100% | 9 | 0 | 0 |  | 100% | 2 | 0 |  | 100%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.proposed_tasks_endpoint |  | 80% | 5 | 1 | 0 |  | 50% | 2 | 1 |  | 71%
src / kiss / agents / sorcar / sorcar.py | run_chatbot._fast_complete |  | 100% | 13 | 0 | 0 |  | 100% | 10 | 0 |  | 100%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.complete |  | 100% | 10 | 0 | 0 |  | 100% | 4 | 0 |  | 100%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.complete._generate |  | 67% | 12 | 4 | 0 |  | 50% | 2 | 1 |  | 64%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.models_endpoint |  | 100% | 8 | 0 | 0 |  | 100% | 4 | 0 |  | 100%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.closing |  | 100% | 2 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.focus_chatbox |  | 100% | 2 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.focus_editor |  | 100% | 4 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.theme |  | 100% | 9 | 0 | 0 |  | 100% | 2 | 0 |  | 100%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.open_file |  | 100% | 11 | 0 | 0 |  | 100% | 4 | 0 |  | 100%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.merge_action |  | 100% | 14 | 0 | 0 |  | 100% | 4 | 0 |  | 100%
src / kiss / agents / sorcar / sorcar.py | run_chatbot._thread_json_response |  | 100% | 4 | 0 | 0 |  | 100% | 2 | 0 |  | 100%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.commit |  | 100% | 2 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.commit._do_commit |  | 80% | 15 | 3 | 0 |  | 100% | 4 | 0 |  | 84%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.push |  | 100% | 2 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.push._do_push |  | 50% | 8 | 4 | 0 |  | 50% | 2 | 1 |  | 50%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.record_file_usage_endpoint |  | 100% | 5 | 0 | 0 |  | 100% | 2 | 0 |  | 100%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.generate_commit_message |  | 100% | 2 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.generate_commit_message._generate |  | 85% | 20 | 3 | 0 |  | 83% | 6 | 1 |  | 85%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.active_file_info |  | 100% | 7 | 0 | 0 |  | 100% | 2 | 0 |  | 100%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.get_file_content |  | 100% | 10 | 0 | 0 |  | 100% | 2 | 0 |  | 100%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.generate_config_message |  | 100% | 4 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src / kiss / agents / sorcar / sorcar.py | run_chatbot.generate_config_message._generate |  | 79% | 14 | 3 | 0 |  | 50% | 2 | 1 |  | 75%
src / kiss / agents / sorcar / sorcar.py | run_chatbot._open_browser |  | 36% | 11 | 7 | 0 |  | 25% | 4 | 1 |  | 33%
src / kiss / agents / sorcar / sorcar.py | run_chatbot._on_exit |  | 0% | 2 | 2 | 0 |  | 100% | 0 | 0 |  | 0%
src / kiss / agents / sorcar / sorcar.py | main |  | 0% | 10 | 10 | 0 |  | 100% | 0 | 0 |  | 0%
src / kiss / agents / sorcar / sorcar.py | (no function) |  | 100% | 39 | 0 | 2 |  | 100% | 0 | 0 |  | 100%
Total |  |  | 77% | 814 | 188 | 2 |  | 75% | 226 | 27 |  | 76%

No items found using the specified filter.